declare namespace Analytics {
    interface Identity {
        userId?: string | number;
        anonymousId?: string | number;
    }
    type Message = Identity & {
        type: string;
        context: {
            library: {
                name: string;
                version: string;
            };
            [key: string]: any;
        };
        _metadata: {
            nodeVersion: string;
            [key: string]: any;
        };
        timestamp?: Date | undefined;
        messageId?: string | undefined;
    };
    interface Data {
        batch: Message[];
        timestamp: Date;
        sentAt: Date;
    }
    interface Integrations {
        [integration_name: string]: IntegrationValue;
    }
    type IntegrationValue = boolean | {
        [integration_key: string]: any;
    };
    class Analytics {
        constructor(writeKey: string, opts?: {
            flushAt?: number | undefined;
            flushInterval?: number | undefined;
            host?: string | undefined;
            enable?: boolean | undefined;
            timeout?: number | string | undefined;
        });
        identify(message: Identity & {
            traits?: any;
            timestamp?: Date | undefined;
            context?: any;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        track(message: Identity & {
            event: string;
            properties?: any;
            timestamp?: Date | undefined;
            context?: any;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        page(message: Identity & {
            category?: string | undefined;
            name?: string | undefined;
            properties?: any;
            timestamp?: Date | undefined;
            context?: any;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        screen(message: Identity & {
            name?: string | undefined;
            properties?: any;
            timestamp?: Date | undefined;
            context?: any;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        alias(message: Identity & {
            previousId: string | number;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        group(message: Identity & {
            groupId: string | number;
            traits?: any;
            context?: any;
            timestamp?: Date | undefined;
            integrations?: Integrations | undefined;
        }, callback?: (err: Error) => void): Analytics;
        flush(callback?: (err: Error, data: Data) => void): Analytics;
    }
}
export default Analytics;
