import { KeyValue, Markdown } from "./core";
export declare type Attachment = string | string[];
export declare type Prop<T = string> = {
    name: string;
    type: string;
    description?: string;
    example?: T | T[];
};
export declare type TextProp<T = string> = Prop<T> & {
    type: 'text' | 'string';
};
export declare type LongTextProp<T = string> = Prop<T> & {
    type: 'longText';
};
export declare type MarkdownProp<T = Markdown> = Prop<T> & {
    type: 'markdown';
};
export declare type AttachmentProp<T = Attachment> = Prop<T> & {
    type: 'attachment';
};
export declare type CheckboxProp<T = boolean> = Prop<T> & {
    type: 'checkbox' | 'bool';
};
export declare type NumberProp<T = number> = Prop<T> & {
    type: 'number';
};
export declare type SingleSelectProp<T = KeyValue<string>[]> = string[] | KeyValue<string>[] | (Prop<T> & {
    options?: string[] | KeyValue<string>[];
    selections?: string | KeyValue<string>;
});
export declare type MultiSelectProp<T = KeyValue<string>[]> = string[] | KeyValue<string>[] | (Prop<T> & {
    options?: string[] | KeyValue[];
    selections?: string[] | KeyValue[];
});
export declare type TextOrNumberProp = TextProp | NumberProp;
export declare type NumberOrNumberProp = number | NumberProp;
export declare const Formula: {
    average: (...props: NumberProp[]) => string;
    count: (...props: NumberProp[]) => string;
    countNonEmpty: (...props: TextOrNumberProp[]) => string;
    countAll: (...props: TextOrNumberProp[]) => string;
    sum: (...props: NumberProp[]) => string;
};
